@@ -288,20 +288,24 @@ Context_new(PyTypeObject* type, PyObject* args, PyObject* kwargs)
     Runtime* runtime = NULL;
     PyObject* global = NULL;
     PyObject* access = NULL;
+    int strict = 0;
+    uint32_t jsopts;
 
-    char* keywords[] = {"runtime", "glbl", "access", NULL};
+    char* keywords[] = {"runtime", "glbl", "access", "strict", NULL};
 
     if(!PyArg_ParseTupleAndKeywords(
         args, kwargs,
-        "O!|OO",
+        "O!|OOI",
         keywords,
         RuntimeType, &runtime,
         &global,
-        &access
+        &access,
+        &strict
     )) goto error;
 
     if(global == Py_None) global = NULL;
     if(access == Py_None) access = NULL;
+    strict &= 1;  /* clamp at 1 */
 
     if(global != NULL && !PyMapping_Check(global))
     {
@@ -378,6 +382,15 @@ Context_new(PyTypeObject* type, PyObject* args, PyObject* kwargs)
 
     JS_SetBranchCallback(self->cx, branch_cb);
     JS_SetErrorReporter(self->cx, report_error_cb);
+
+    jsopts = JS_GetOptions(self->cx);
+    jsopts |= JSOPTION_VAROBJFIX;
+    if (strict) {
+        jsopts |= JSOPTION_STRICT;
+    } else {
+        jsopts &= ~JSOPTION_STRICT;
+    }
+    JS_SetOptions(self->cx, jsopts);
     
     Py_INCREF(runtime);
     self->rt = runtime;
@@ -546,11 +559,18 @@ Context_execute(Context* self, PyObject* args, PyObject* kwargs)
     JSString* script = NULL;
     jschar* schars = NULL;
     JSBool started_counter = JS_FALSE;
+    char *fname = "<anonymous JavaScript>";
+    unsigned int lineno = 1;
     size_t slen;
     jsval rval;
 
+    char *keywords[] = {"code", "filename", "lineno", NULL};
+
+    if(!PyArg_ParseTupleAndKeywords(args, kwargs, "O|sI", keywords,
+                                    &obj, &fname, &lineno))
+        goto error;
+
     JS_BeginRequest(self->cx);
-    if(!PyArg_ParseTuple(args, "O", &obj)) goto error;
     
     script = py2js_string_obj(self, obj);
     if(script == NULL) goto error;
@@ -568,11 +588,11 @@ Context_execute(Context* self, PyObject* args, PyObject* kwargs)
         self->start_time = time(NULL);
     }
 
-    if(!JS_EvaluateUCScript(cx, root, schars, slen, "<JavaScript>", 1, &rval))
+    if(!JS_EvaluateUCScript(cx, root, schars, slen, fname, lineno, &rval))
     {
         if(!PyErr_Occurred())
         {
-            PyErr_SetString(PyExc_RuntimeError, "Failed to execute script.");
+            PyErr_SetString(PyExc_RuntimeError, "Script execution failed and no exception was set");
         }
         goto error;
     }
@@ -666,7 +686,7 @@ static PyMethodDef Context_methods[] = {
     {
         "execute",
         (PyCFunction)Context_execute,
-        METH_VARARGS,
+        METH_VARARGS | METH_KEYWORDS,
         "Execute JavaScript source code."
     },
     {
