@@ -75,16 +75,24 @@ success:
 void
 report_error_cb(JSContext* cx, const char* message, JSErrorReport* report)
 {
+    /* Subtle note about JSREPORT_EXCEPTION: it triggers whenever exceptions
+     * are raised, even if they're caught and the Mozilla docs say you can
+     * ignore it.
+     */
+    /* TODO What should we do about warnings? A callback somehow? */
+    if (report->flags & JSREPORT_WARNING)
+        return;
+
     const char* srcfile = report->filename;
     const char* mesg = message;
 
+    if(srcfile == NULL) srcfile = "<JavaScript>";
+    if(mesg == NULL) mesg = "Unknown JavaScript execution error";
+
     if(!PyErr_Occurred())
     {
-        PyErr_SetString(JSError, "Error executing JavaScript.");
+        PyErr_SetString(JSError, message);
     }
 
-    if(srcfile == NULL) srcfile = "<JavaScript>";
-    if(mesg == NULL) mesg = "<Unknown Error>";
-    
-    add_frame(srcfile, mesg, report->lineno);
+    add_frame(srcfile, "JavaScript code", report->lineno);
 }
